## gopup (python3)

#### 建议安装方法
    pip install gopup

#### 升级方法
    pip install gopup --upgrade

GoPUP 支持Python 3.6+，旨在使获取数据尽可能方便。

文档：[中文文档](https://gopup-cookbook.readthedocs.io) 

### 数据目录

- 数据仓库
    - 指数数据
        - 微博指数数据
        - 百度搜索数据
        - 百度资讯指数
        - 百度媒体指数
    - 疫情数据
        - 网易疫情数据
        - 丁香园疫情数据
        - 疫情历史数据
        - 百度疫情数据
        - 百度迁徙数据